@@ -34,36 +34,41 @@
 #endif
 
 /* support macros for debugging (improved macro for better position indication) */
-/*#ifndef NDEBUG*/
-#define panel_assert(expr)                 g_assert (expr)
-#define panel_assert_not_reached()         g_assert_not_reached ()
-#define panel_return_if_fail(expr)         G_STMT_START { \
-  if (G_UNLIKELY (!(expr))) \
-    { \
-      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, \
-             "%s (%s): expression '%s' failed.", G_STRLOC, G_STRFUNC, \
-             #expr); \
-      return; \
-    }; }G_STMT_END
-#define panel_return_val_if_fail(expr,val) G_STMT_START { \
-  if (G_UNLIKELY (!(expr))) \
-    { \
-      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, \
-             "%s (%s): expression '%s' failed.", G_STRLOC, G_STRFUNC, \
-             #expr); \
-      return (val); \
-    }; }G_STMT_END
-/*#else
-#define panel_assert(expr)                 G_STMT_START{ (void)0; }G_STMT_END
-#define panel_assert_not_reached()         G_STMT_START{ (void)0; }G_STMT_END
-#define panel_return_if_fail(expr)         G_STMT_START{ (void)0; }G_STMT_END
-#define panel_return_val_if_fail(expr,val) G_STMT_START{ (void)0; }G_STMT_END
-#endif*/
+#define panel_assert(expr) g_assert (expr)
+#define panel_assert_not_reached() g_assert_not_reached ()
+#define panel_return_if_fail(expr) \
+  G_STMT_START \
+  { \
+    if (G_UNLIKELY (!(expr))) \
+      { \
+        g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, \
+               "%s (%s): expression '%s' failed.", G_STRLOC, G_STRFUNC, \
+               #expr); \
+        return; \
+      }; \
+  } \
+  G_STMT_END
+#define panel_return_val_if_fail(expr, val) \
+  G_STMT_START \
+  { \
+    if (G_UNLIKELY (!(expr))) \
+      { \
+        g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, \
+               "%s (%s): expression '%s' failed.", G_STRLOC, G_STRFUNC, \
+               #expr); \
+        return (val); \
+      }; \
+  } \
+  G_STMT_END
 
 /* handling flags */
-#define PANEL_SET_FLAG(flags,flag) G_STMT_START{ ((flags) |= (flag)); }G_STMT_END
-#define PANEL_UNSET_FLAG(flags,flag) G_STMT_START{ ((flags) &= ~(flag)); }G_STMT_END
-#define PANEL_HAS_FLAG(flags,flag) (((flags) & (flag)) != 0)
+#define PANEL_SET_FLAG(flags, flag) \
+  G_STMT_START { ((flags) |= (flag)); } \
+  G_STMT_END
+#define PANEL_UNSET_FLAG(flags, flag) \
+  G_STMT_START { ((flags) &= ~(flag)); } \
+  G_STMT_END
+#define PANEL_HAS_FLAG(flags, flag) (((flags) & (flag)) != 0)
 
 /* relative path to the plugin directory */
 #define PANEL_PLUGIN_RELATIVE_PATH "xfce4" G_DIR_SEPARATOR_S "panel"
@@ -83,13 +88,25 @@
 #define PANEL_PLUGIN_AUTO_RESTART (60)
 
 /* integer swap functions */
-#define SWAP_INTEGER(a,b) G_STMT_START { gint swp = a; a = b; b = swp; } G_STMT_END
-#define TRANSPOSE_AREA(area) G_STMT_START { SWAP_INTEGER (area.width, area.height); \
-                                            SWAP_INTEGER (area.x, area.y); } G_STMT_END
+#define SWAP_INTEGER(a, b) \
+  G_STMT_START \
+  { \
+    gint swp = a; \
+    a = b; \
+    b = swp; \
+  } \
+  G_STMT_END
+#define TRANSPOSE_AREA(area) \
+  G_STMT_START \
+  { \
+    SWAP_INTEGER (area.width, area.height); \
+    SWAP_INTEGER (area.x, area.y); \
+  } \
+  G_STMT_END
 
 /* quick GList and GSList counting without traversing */
-#define LIST_HAS_ONE_ENTRY(l)           ((l) != NULL && (l)->next == NULL)
-#define LIST_HAS_ONE_OR_NO_ENTRIES(l)   ((l) == NULL || (l)->next == NULL)
+#define LIST_HAS_ONE_ENTRY(l) ((l) != NULL && (l)->next == NULL)
+#define LIST_HAS_ONE_OR_NO_ENTRIES(l) ((l) == NULL || (l)->next == NULL)
 #define LIST_HAS_TWO_OR_MORE_ENTRIES(l) ((l) != NULL && (l)->next != NULL)
 
 /* group deprecations we don't want to replace */
@@ -97,57 +114,57 @@ static inline void
 panel_image_menu_item_set_image (GtkWidget *image_menu_item,
                                  GtkWidget *image)
 {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (image_menu_item), image);
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static inline GtkWidget *
 panel_image_menu_item_new (void)
 {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   return gtk_image_menu_item_new ();
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static inline GtkWidget *
 panel_image_menu_item_new_with_label (const gchar *label)
 {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   return gtk_image_menu_item_new_with_label (label);
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static inline GtkWidget *
 panel_image_menu_item_new_with_mnemonic (const gchar *label)
 {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   return gtk_image_menu_item_new_with_mnemonic (label);
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static inline gint
 panel_screen_get_number (GdkScreen *screen)
 {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   return gdk_screen_get_number (screen);
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static inline gint
 panel_screen_get_width (GdkScreen *screen)
 {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   return gdk_screen_get_width (screen);
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static inline gint
 panel_screen_get_height (GdkScreen *screen)
 {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   return gdk_screen_get_height (screen);
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 #endif /* !__PANEL_PRIVATE_H__ */
