@@ -19,19 +19,23 @@
 #ifndef __PANEL_DBUS_SERVICE_H__
 #define __PANEL_DBUS_SERVICE_H__
 
+#include "panel/panel-gdbus-exported-service.h"
+
 #include <glib.h>
-#include <panel/panel-gdbus-exported-service.h>
 
 G_BEGIN_DECLS
 
 #define PANEL_TYPE_DBUS_SERVICE (panel_dbus_service_get_type ())
 G_DECLARE_FINAL_TYPE (PanelDBusService, panel_dbus_service, PANEL, DBUS_SERVICE, XfcePanelExportedServiceSkeleton)
 
-PanelDBusService   *panel_dbus_service_get         (void);
+PanelDBusService *
+panel_dbus_service_get (void);
 
-void                panel_dbus_service_exit_panel  (gboolean          restart);
+void
+panel_dbus_service_exit_panel (gboolean restart);
 
-gboolean            panel_dbus_service_get_restart (void);
+gboolean
+panel_dbus_service_get_restart (void);
 
 G_END_DECLS
 
