@@ -19,23 +19,23 @@
 #ifndef __PANEL_ITEM_DIALOG_H__
 #define __PANEL_ITEM_DIALOG_H__
 
-#include <gtk/gtk.h>
-
 /* includes libxfce4ui and the definition of glib_autoptr_clear_XfceTitledDialog */
-#include <panel/panel-tic-tac-toe.h>
+#include "panel/panel-tic-tac-toe.h"
 
 G_BEGIN_DECLS
 
 #define PANEL_TYPE_ITEM_DIALOG (panel_item_dialog_get_type ())
 G_DECLARE_FINAL_TYPE (PanelItemDialog, panel_item_dialog, PANEL, ITEM_DIALOG, XfceTitledDialog)
 
-void       panel_item_dialog_show         (PanelWindow *active);
+void
+panel_item_dialog_show (PanelWindow *active);
 
-void       panel_item_dialog_show_from_id (gint         panel_id);
+void
+panel_item_dialog_show_from_id (gint panel_id);
 
-gboolean   panel_item_dialog_visible      (void);
+gboolean
+panel_item_dialog_visible (void);
 
 G_END_DECLS
 
 #endif /* !__PANEL_ITEM_DIALOG_H__ */
-
