@@ -17,40 +17,41 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <gmodule.h>
+#include "panel/panel-module-factory.h"
+#include "panel/panel-module.h"
+#include "panel/panel-plugin-external-wrapper.h"
+
+#include "common/panel-debug.h"
+#include "common/panel-private.h"
+
 #include <glib/gstdio.h>
+#include <gmodule.h>
 #include <libxfce4util/libxfce4util.h>
+
 #ifdef HAVE_GTK_LAYER_SHELL
 #include <gtk-layer-shell/gtk-layer-shell.h>
 #else
 #define gtk_layer_is_supported() FALSE
 #endif
 
-#include <common/panel-private.h>
-#include <common/panel-debug.h>
-#include <libxfce4panel/libxfce4panel.h>
-#include <libxfce4panel/xfce-panel-plugin-provider.h>
-
-#include <panel/panel-module.h>
-#include <panel/panel-module-factory.h>
-#include <panel/panel-plugin-external-wrapper.h>
-
-#define PANEL_PLUGINS_LIB_DIR (LIBDIR G_DIR_SEPARATOR_S "panel" G_DIR_SEPARATOR_S "plugins")
-#define PANEL_PLUGINS_LIB_DIR_OLD (LIBDIR G_DIR_SEPARATOR_S "panel-plugins")
 
 
-typedef enum _PanelModuleUnique  PanelModuleUnique;
+typedef enum _PanelModuleUnique PanelModuleUnique;
 
 
 
-static void      panel_module_dispose          (GObject          *object);
-static gboolean  panel_module_load             (GTypeModule      *type_module);
-static void      panel_module_unload           (GTypeModule      *type_module);
-static void      panel_module_plugin_destroyed (gpointer          user_data,
-                                                GObject          *where_the_plugin_was);
+static void
+panel_module_dispose (GObject *object);
+static gboolean
+panel_module_load (GTypeModule *type_module);
+static void
+panel_module_unload (GTypeModule *type_module);
+static void
+panel_module_plugin_destroyed (gpointer user_data,
+                               GObject *where_the_plugin_was);
 
 
 
@@ -66,31 +67,31 @@ struct _PanelModule
   GTypeModule __parent__;
 
   /* module type */
-  PanelModuleRunMode   mode;
+  PanelModuleRunMode mode;
 
   /* filename of the library */
-  gchar               *filename;
+  gchar *filename;
 
   /* plugin information from the desktop file */
-  gchar               *display_name;
-  gchar               *comment;
-  gchar               *icon_name;
+  gchar *display_name;
+  gchar *comment;
+  gchar *icon_name;
 
   /* unique handling */
-  guint                use_count;
-  PanelModuleUnique    unique_mode;
+  guint use_count;
+  PanelModuleUnique unique_mode;
 
   /* module location */
-  GModule             *library;
+  GModule *library;
 
   /* for non-gobject plugin */
-  PluginConstructFunc  construct_func;
+  PluginConstructFunc construct_func;
 
   /* for gobject plugins */
-  GType                plugin_type;
+  GType plugin_type;
 
   /* for wrapper plugins */
-  gchar               *api;
+  gchar *api;
 };
 
 
@@ -106,7 +107,7 @@ G_DEFINE_FINAL_TYPE (PanelModule, panel_module, G_TYPE_TYPE_MODULE)
 static void
 panel_module_class_init (PanelModuleClass *klass)
 {
-  GObjectClass     *gobject_class;
+  GObjectClass *gobject_class;
   GTypeModuleClass *gtype_module_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
@@ -168,10 +169,10 @@ panel_module_dispose (GObject *object)
 static gboolean
 panel_module_load (GTypeModule *type_module)
 {
-  PanelModule    *module = PANEL_MODULE (type_module);
-  PluginInitFunc  init_func;
-  gboolean        make_resident = TRUE;
-  gpointer        foo;
+  PanelModule *module = PANEL_MODULE (type_module);
+  PluginInitFunc init_func;
+  gboolean make_resident = TRUE;
+  gpointer foo;
 
   panel_return_val_if_fail (PANEL_IS_MODULE (module), FALSE);
   panel_return_val_if_fail (G_IS_TYPE_MODULE (module), FALSE);
@@ -190,14 +191,15 @@ panel_module_load (GTypeModule *type_module)
       return FALSE;
     }
 
-    /* check if there is a preinit function */
+  /* check if there is a preinit function */
   if (g_module_symbol (module->library, "xfce_panel_module_preinit", &foo))
     {
       /* large message, but technically never shown to normal users */
       g_warning ("The plugin \"%s\" is marked as internal in the desktop file, "
                  "but the developer has defined an pre-init function, which is "
                  "not supported for internal plugins. " PACKAGE_NAME " will force "
-                 "the plugin to run external.", module->filename);
+                 "the plugin to run external.",
+                 module->filename);
 
       panel_module_unload (type_module);
 
@@ -258,8 +260,8 @@ panel_module_unload (GTypeModule *type_module)
 
 
 static void
-panel_module_plugin_destroyed (gpointer  user_data,
-                               GObject  *where_the_plugin_was)
+panel_module_plugin_destroyed (gpointer user_data,
+                               GObject *where_the_plugin_was)
 {
   PanelModule *module = PANEL_MODULE (user_data);
 
@@ -284,14 +286,15 @@ panel_module_plugin_destroyed (gpointer  user_data,
 PanelModule *
 panel_module_new_from_desktop_file (const gchar *filename,
                                     const gchar *name,
+                                    const gchar *libdir,
                                     PanelModuleRunMode forced_mode)
 {
   PanelModule *module = NULL;
-  XfceRc      *rc;
+  XfceRc *rc;
   const gchar *module_name;
-  gchar       *path;
+  gchar *path;
   const gchar *module_unique;
-  gboolean     found;
+  gboolean found;
 
   panel_return_val_if_fail (!xfce_str_is_empty (filename), NULL);
   panel_return_val_if_fail (!xfce_str_is_empty (name), NULL);
@@ -306,8 +309,8 @@ panel_module_new_from_desktop_file (const gchar *filename,
 
   if (!xfce_rc_has_group (rc, "Xfce Panel"))
     {
-      g_critical ("Plugin %s: Desktop file \"%s\" has no "
-                  "\"Xfce Panel\" group", name, filename);
+      g_critical ("Plugin %s: Desktop file \"%s\" has no \"Xfce Panel\" group",
+                  name, filename);
       xfce_rc_close (rc);
       return NULL;
     }
@@ -315,7 +318,8 @@ panel_module_new_from_desktop_file (const gchar *filename,
   if (g_strcmp0 (xfce_rc_read_entry (rc, "X-XFCE-API", "1.0"), "2.0") != 0)
     {
       g_critical ("Plugin %s: The Desktop file %s requested the Gtk2 API (v1.0), which is "
-                  "no longer supported.", name, filename);
+                  "no longer supported.",
+                  name, filename);
       xfce_rc_close (rc);
       return NULL;
     }
@@ -326,28 +330,9 @@ panel_module_new_from_desktop_file (const gchar *filename,
   module_name = xfce_rc_read_entry_untranslated (rc, "X-XFCE-Module", NULL);
   if (G_LIKELY (module_name != NULL))
     {
-#ifndef NDEBUG
-      if (xfce_rc_has_entry (rc, "X-XFCE-Module-Path"))
-        {
-          /* show a messsage if the old module path key still exists */
-          g_message ("Plugin %s: The \"X-XFCE-Module-Path\" key is "
-                     "ignored in \"%s\", the panel will look for the "
-                     "module in %s. See bug #5455 why this decision was made",
-                     name, filename, PANEL_PLUGINS_LIB_DIR);
-        }
-#endif
-
-      path = g_module_build_path (PANEL_PLUGINS_LIB_DIR, module_name);
+      path = g_module_build_path (libdir, module_name);
       found = g_file_test (path, G_FILE_TEST_EXISTS);
 
-      if (!found)
-        {
-          /* deprecated location for module plugin directories */
-          g_free (path);
-          path = g_module_build_path (PANEL_PLUGINS_LIB_DIR_OLD, module_name);
-          found = g_file_test (path, G_FILE_TEST_EXISTS);
-        }
-
       if (G_LIKELY (found))
         {
           /* create new module */
@@ -370,8 +355,11 @@ panel_module_new_from_desktop_file (const gchar *filename,
         }
       else
         {
-          g_critical ("Plugin %s: There was no module found at \"%s\"",
-                      name, path);
+          if (g_strcmp0 (libdir, LIBDIR) == 0)
+            g_critical ("Plugin %s: There was no module found at \"%s\"", name, path);
+          else
+            panel_debug_filtered (PANEL_DEBUG_MODULE, "Plugin %s: There was no module found at \"%s\"", name, path);
+
           g_free (path);
         }
     }
@@ -396,9 +384,9 @@ panel_module_new_from_desktop_file (const gchar *filename,
       else
         module->unique_mode = UNIQUE_FALSE;
 
-       panel_debug_filtered (PANEL_DEBUG_MODULE, "new module %s, filename=%s, internal=%s",
-                             name, module->filename,
-                             PANEL_DEBUG_BOOL (module->mode == PANEL_MODULE_RUN_MODE_INTERNAL));
+      panel_debug_filtered (PANEL_DEBUG_MODULE, "new module %s, filename=%s, internal=%s",
+                            name, module->filename,
+                            PANEL_DEBUG_BOOL (module->mode == PANEL_MODULE_RUN_MODE_INTERNAL));
     }
 
   xfce_rc_close (rc);
@@ -409,12 +397,12 @@ panel_module_new_from_desktop_file (const gchar *filename,
 
 
 GtkWidget *
-panel_module_new_plugin (PanelModule  *module,
-                         GdkScreen    *screen,
-                         gint          unique_id,
-                         gchar       **arguments)
+panel_module_new_plugin (PanelModule *module,
+                         GdkScreen *screen,
+                         gint unique_id,
+                         gchar **arguments)
 {
-  GtkWidget   *plugin = NULL;
+  GtkWidget *plugin = NULL;
   const gchar *debug_type = NULL;
 
   panel_return_val_if_fail (PANEL_IS_MODULE (module), NULL);
@@ -485,11 +473,10 @@ panel_module_new_plugin (PanelModule  *module,
       module->use_count++;
 
       panel_debug (PANEL_DEBUG_MODULE, "new item (type=%s, name=%s, id=%d)",
-          debug_type, panel_module_get_name (module), unique_id);
+                   debug_type, panel_module_get_name (module), unique_id);
 
       /* handle module use count and unloading */
-      g_object_weak_ref (G_OBJECT (plugin),
-          panel_module_plugin_destroyed, module);
+      g_object_weak_ref (G_OBJECT (plugin), panel_module_plugin_destroyed, module);
 
       /* add link to the module */
       g_object_set_qdata (G_OBJECT (plugin), module_quark, module);
@@ -528,7 +515,8 @@ panel_module_get_display_name (PanelModule *module)
   panel_return_val_if_fail (PANEL_IS_MODULE (module), NULL);
   panel_return_val_if_fail (G_IS_TYPE_MODULE (module), NULL);
   panel_return_val_if_fail (module->display_name == NULL
-                            || g_utf8_validate (module->display_name, -1, NULL), NULL);
+                              || g_utf8_validate (module->display_name, -1, NULL),
+                            NULL);
 
   return module->display_name;
 }
@@ -540,7 +528,8 @@ panel_module_get_comment (PanelModule *module)
 {
   panel_return_val_if_fail (PANEL_IS_MODULE (module), NULL);
   panel_return_val_if_fail (module->comment == NULL
-                            || g_utf8_validate (module->comment, -1, NULL), NULL);
+                              || g_utf8_validate (module->comment, -1, NULL),
+                            NULL);
 
   return module->comment;
 }
@@ -552,7 +541,8 @@ panel_module_get_icon_name (PanelModule *module)
 {
   panel_return_val_if_fail (PANEL_IS_MODULE (module), NULL);
   panel_return_val_if_fail (module->icon_name == NULL
-                            || g_utf8_validate (module->icon_name, -1, NULL), NULL);
+                              || g_utf8_validate (module->icon_name, -1, NULL),
+                            NULL);
 
   return module->icon_name;
 }
@@ -603,11 +593,11 @@ panel_module_is_unique (PanelModule *module)
 
 gboolean
 panel_module_is_usable (PanelModule *module,
-                        GdkScreen   *screen)
+                        GdkScreen *screen)
 {
   PanelModuleFactory *factory;
-  GSList             *plugins, *li;
-  gboolean            usable = TRUE;
+  GSList *plugins, *li;
+  gboolean usable = TRUE;
 
   panel_return_val_if_fail (PANEL_IS_MODULE (module), FALSE);
   panel_return_val_if_fail (GDK_IS_SCREEN (screen), FALSE);
