@@ -19,26 +19,29 @@
 #ifndef __PANEL_PREFERENCES_DIALOG_H__
 #define __PANEL_PREFERENCES_DIALOG_H__
 
+#include "panel/panel-window.h"
+
 #include <gtk/gtk.h>
 #ifdef ENABLE_X11
 #include <gtk/gtkx.h>
 #else
 typedef gulong Window;
 #endif
-#include <panel/panel-application.h>
-#include <panel/panel-window.h>
 
 G_BEGIN_DECLS
 
 #define PANEL_TYPE_PREFERENCES_DIALOG (panel_preferences_dialog_get_type ())
 G_DECLARE_FINAL_TYPE (PanelPreferencesDialog, panel_preferences_dialog, PANEL, PREFERENCES_DIALOG, GtkBuilder)
 
-void       panel_preferences_dialog_show         (PanelWindow *active);
+void
+panel_preferences_dialog_show (PanelWindow *active);
 
-void       panel_preferences_dialog_show_from_id (gint         panel_id,
-                                                  Window       socket_window);
+void
+panel_preferences_dialog_show_from_id (gint panel_id,
+                                       Window socket_window);
 
-gboolean   panel_preferences_dialog_visible      (void);
+gboolean
+panel_preferences_dialog_visible (void);
 
 G_END_DECLS
 
